.. image:: https://travis-ci.org/ambitioninc/django-entity-event.png
   :target: https://travis-ci.org/ambitioninc/django-entity-event

.. image:: https://coveralls.io/repos/ambitioninc/django-entity-event/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/django-entity-event?branch=develop

.. image:: https://pypip.in/v/django-entity-event/badge.png
    :target: https://crate.io/packages/django-entity-event/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/django-entity-event/badge.png
    :target: https://crate.io/packages/django-entity-event/
    :alt: Number of PyPI downloads


django-entity-event
===============

Newsfeed-style event tracking and subscription management for django-entity.

Installation
------------
To install the latest release, type::

    pip install django-entity-event

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-entity-event.git

Documentation
=============

Full documentation is available at http://django-entity-event.readthedocs.org

License
=======
MIT License (see LICENSE)
